@@ -7,6 +7,7 @@ import shutil
 import sys
 import tkinter as tk
 import threading
+import unicodedata
 from tkinter import filedialog, messagebox
 
 import cv2
@@ -43,6 +44,7 @@ class LabelOcrApp:
         self.label_in_filename = None  # Not use in the future
         self.image_name = builder.get_variable("var_image_name")
         self.label_ocr = builder.get_variable("var_label")
+        self.label_ocr_show = builder.get_variable("var_label_show")
         self.cur_index = builder.get_variable("var_cur_index")
         self.txt_label = builder.get_object("txt_label")
 
@@ -50,8 +52,24 @@ class LabelOcrApp:
 
         self.canvas = builder.get_object("canvas")
         self.lbl_image = builder.get_object("lbl_image")
+
         self.btn_keep_exist_label = builder.get_object("btn_keep_exist_label")
-        self.keep_exist_label = True#builder.get_variable("keep_exist_label")
+        self.keep_exist_label = True
+        self.btn_keep_exist_label.select()
+
+        self.btn_remove_accent = builder.get_object("btn_remove_accent")
+        self.remove_accent = False
+
+        self.btn_upper = builder.get_object("btn_upper")
+        self.upper_case = False
+
+        self.btn_title = builder.get_object("btn_title")
+        self.title_case = False
+
+        self.btn_lower = builder.get_object("btn_lower")
+        self.lower_case = False
+
+
 
         self.progress_label = builder.get_variable("var_progress_label")
 
@@ -134,12 +152,66 @@ class LabelOcrApp:
 
     def change_keep_exist_label(self, event=None):
         self.keep_exist_label = not self.keep_exist_label
+        LOGGER.info(f"Change_keep_exist_label: {self.keep_exist_label}")
         if self.keep_exist_label:
             self.btn_keep_exist_label.select()
         else:
             self.btn_keep_exist_label.deselect()
         self._show_image()
 
+    def change_remove_accent(self, event=None):
+        self.remove_accent = not self.remove_accent
+        LOGGER.info(f"change_remove_accent: {self.remove_accent}")
+        if self.remove_accent:
+            self.btn_remove_accent.select()
+        else:
+            self.btn_remove_accent.deselect()
+        self._show_image()
+
+    def change_upper(self, event=None):
+        if self.title_case:
+            self.change_title()
+        if self.lower_case:
+            self.change_lower()
+
+        self.upper_case = not self.upper_case
+        LOGGER.info(f"change_upper: {self.upper_case}")
+        if self.upper_case:
+            self.btn_upper.select()
+        else:
+            self.btn_upper.deselect()
+        self._show_image()
+
+    def change_title(self, event=None):
+        if self.upper_case:
+            self.change_upper()
+        if self.lower_case:
+            self.change_lower()
+
+        self.title_case = not self.title_case
+        LOGGER.info(f"change_title: {self.title_case}")
+
+        if self.title_case:
+            self.btn_title.select()
+        else:
+            self.btn_title.deselect()
+        self._show_image()
+
+    def change_lower(self, event=None):
+        if self.title_case:
+            self.change_title()
+        if self.upper_case:
+            self.change_upper()
+
+        self.lower_case = not self.lower_case
+        LOGGER.info(f"change_lower: {self.lower_case}")
+
+        if self.lower_case:
+            self.btn_lower.select()
+        else:
+            self.btn_lower.deselect()
+        self._show_image()
+
     def clean_text(self, event=None):
         self.label_ocr.set("")
 
@@ -227,9 +299,23 @@ class LabelOcrApp:
 
         self.scale_image()
         # self.canvas.create_image(0, 0, image=img_origin, anchor=tk.NW)
-        self.label_ocr.set("")
+        if self.remove_accent:
+            label = remove_accents(label)
+
+        if self.upper_case:
+            label = label.upper()
+
+        if self.lower_case:
+            label = label.lower()
+
+        if self.title_case:
+            label = label.title()
+
+        self.label_ocr_show.set(label)
         if self.keep_exist_label:
             self.label_ocr.set(label)
+        else:
+            self.label_ocr.set("")
 
         self.progress_label.set((self.index + 1) / len(self.list_label))
         self.cur_index.set(f"Index: {self.index + 1}/{len(self.list_file)}")
@@ -260,7 +346,9 @@ class LabelOcrApp:
 
     def _save_label(self):
         if self.index is not None and self.index >= 0:
-            self.list_label[self.index] = self.label_ocr.get().strip()
+            if len(self.label_ocr.get().strip()) > 0:
+                self.label_ocr_show.set(self.label_ocr.get())
+            self.list_label[self.index] = self.label_ocr_show.get().strip()
 
     def show_exception_and_exit(self, exc_type, exc_value, tb):
         import traceback
@@ -292,6 +380,14 @@ class LabelOcrApp:
         return Image.fromarray(mask.astype(np.uint8))
 
 
+def remove_accents(input_str):
+    if input_str is None:
+        return None
+    nfkd_form = unicodedata.normalize('NFKD', input_str)
+    only_ascii = nfkd_form.encode('ASCII', 'ignore')
+    return only_ascii.decode('utf8')
+
+
 NULL_CHAR = '<nul>'
 LONGEST_TEXT = ''
 CHARSET_CONTAINS = set()
